==> robot_descriptions-0.2.0.tar.gz: robot_descriptions-0.2.0/robot_descriptions/_description_names.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Copyright 2022 Stéphane Caron
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
List of all robot descriptions.
"""

from typing import List

DESCRIPTION_NAMES: List[str] = [
    "a1_description",
    "aliengo_description",
    "aliengo_mj_description",
    "allegro_hand_description",
    "anymal_b_description",
    "anymal_c_description",
    "atlas_description",
    "baxter_description",
    "bolt_description",
    "cassie_description",
    "cassie_mj_description",
    "cf2_description",
    "double_pendulum_description",
    "edo_description",
    "finger_edu_description",
    "gen2_description",
    "hyq_description",
    "icub_description",
    "iiwa_description",
    "jvrc_description",
    "jvrc_mj_description",
    "laikago_description",
    "mini_cheetah_description",
    "minitaur_description",
    "panda_description",
    "pr2_description",
    "reachy_description",
    "romeo_description",
    "simple_humanoid_description",
    "solo_description",
    "talos_description",
    "tiago_description",
    "upkie_description",
    "ur10_description",
    "ur3_description",
    "ur5_description",
]

==> robot_descriptions-0.3.0.tar.gz: robot_descriptions-0.3.0/robot_descriptions/_description_names.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Copyright 2022 Stéphane Caron
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
List of all robot descriptions.
"""

from typing import List

DESCRIPTION_NAMES: List[str] = [
    "a1_description",
    "aliengo_description",
    "allegro_hand_description",
    "anymal_b_description",
    "anymal_b_mj_description",
    "anymal_c_description",
    "anymal_c_mj_description",
    "atlas_drc_description",
    "atlas_v4_description",
    "baxter_description",
    "bolt_description",
    "cassie_description",
    "cassie_mj_description",
    "cf2_description",
    "double_pendulum_description",
    "edo_description",
    "fetch_description",
    "finger_edu_description",
    "gen2_description",
    "ginger_description",
    "go1_description",
    "hyq_description",
    "icub_description",
    "iiwa_description",
    "jvrc_description",
    "jvrc_mj_description",
    "laikago_description",
    "mini_cheetah_description",
    "minitaur_description",
    "panda_description",
    "panda_mj_description",
    "pepper_description",
    "pr2_description",
    "reachy_description",
    "robotiq_2f85_description",
    "robotiq_2f85_mj_description",
    "romeo_description",
    "shadow_hand_mj_description",
    "simple_humanoid_description",
    "solo_description",
    "talos_description",
    "tiago_description",
    "upkie_description",
    "ur10_description",
    "ur3_description",
    "ur5_description",
    "ur5e_mj_description",
    "yumi_description",
]
